@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.modelkit");
-Clazz.load (["J.popup.JmolGenericPopup", "java.util.Hashtable", "JU.BS", "$.P3", "J.i18n.GT", "J.modelkit.ModelKitPopupResourceBundle"], "J.modelkit.ModelKitPopup", ["java.lang.Boolean", "$.Float", "JU.PT", "$.SB", "$.V3", "JM.Atom", "JU.BSUtil", "$.Edge", "$.Elements", "$.Logger"], function () {
+Clazz.load (["J.popup.JmolGenericPopup", "java.util.Hashtable", "JU.BS", "$.P3", "J.i18n.GT", "J.modelkit.ModelKitPopupResourceBundle"], "J.modelkit.ModelKitPopup", ["java.lang.Boolean", "$.Float", "JU.AU", "$.Lst", "$.PT", "$.SB", "$.V3", "JM.Atom", "JU.BSUtil", "$.Edge", "$.Elements", "$.Escape", "$.Logger"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.hasUnitCell = false;
 this.allOperators = null;
@@ -182,9 +182,10 @@ function (source, actionCommand, selected) {
 var name = source.getName ();
 if (!this.updatingForShow && this.setActiveMenu (name) != null) {
 var text = source.getText ();
-if (name.indexOf ("Bond") >= 0) {
+System.out.println ("MKP " + this.activeMenu + " " + name + " / " + text);
+if (this.activeMenu === "bondMenu") {
 this.bondHoverLabel = text;
-} else if (name.indexOf ("assignAtom") >= 0) this.atomHoverLabel = text;
+} else if (this.activeMenu === "atomMenu") this.atomHoverLabel = text;
  else if (this.activeMenu === "xtalMenu") this.xtalHoverLabel = this.atomHoverLabel = text;
 }}, "J.api.SC,~S,~B");
 Clazz.defineMethod (c$, "isXtalState", 
@@ -235,8 +236,18 @@ return this.setProperty (key, value);
 }, "~O");
 Clazz.defineMethod (c$, "setProperty", 
 function (name, value) {
+try {
 name = name.toLowerCase ().intern ();
-if (name === "ismolecular") {
+if (name === "addhydrogen" || name === "addhydrogens") {
+if (value != null) this.addXtalHydrogens = J.modelkit.ModelKitPopup.isTrue (value);
+return Boolean.$valueOf (this.addXtalHydrogens);
+}if (name === "clicktosetelement") {
+if (value != null) this.clickToSetElement = J.modelkit.ModelKitPopup.isTrue (value);
+return Boolean.$valueOf (this.clickToSetElement);
+}if (name === "showsymopinfo") {
+if (value != null) this.showSymopInfo = J.modelkit.ModelKitPopup.isTrue (value);
+return Boolean.$valueOf (this.showSymopInfo);
+}if (name === "ismolecular") {
 return Boolean.$valueOf (this.getMKState () == 0);
 }if (name === "hoverlabel") {
 return this.getHoverLabel ((value).intValue ());
@@ -254,9 +265,9 @@ var o = (value);
 var type = o[0];
 var data = o[1];
 var atomIndex = data[0];
-if (this.isVwrRotateBond ()) {
-this.bondAtomIndex1 = atomIndex;
-} else if (!this.processAtomClick (data[0]) && (this.clickToSetElement || this.vwr.ms.getAtom (atomIndex).getElementNumber () == 1)) this.assignAtom (atomIndex, type, data[1] >= 0, data[2] >= 0);
+var autoBond = (data[1] >= 0);
+var addHsAndBond = (data[2] >= 0);
+this.assignAtom (atomIndex, type, autoBond, addHsAndBond, true);
 return null;
 }if (name === "bondatomindex") {
 var i = (value).intValue ();
@@ -291,19 +302,16 @@ this.showSymop (this.symop);
 }return this.symop;
 }if (name === "center") {
 this.setDefaultState (1);
-var centerAtom = value;
-this.lastCenter = centerAtom.x + " " + centerAtom.y + " " + centerAtom.z;
-this.centerAtomIndex = (Clazz.instanceOf (centerAtom, JM.Atom) ? (centerAtom).i : -1);
+this.centerPoint = value;
+this.lastCenter = this.centerPoint.x + " " + this.centerPoint.y + " " + this.centerPoint.z;
+this.centerAtomIndex = (Clazz.instanceOf (this.centerPoint, JM.Atom) ? (this.centerPoint).i : -1);
 this.atomIndexSphere = -1;
 this.secondAtomIndex = -1;
 this.processAtomClick (this.centerAtomIndex);
 return null;
 }if (name === "scriptassignbond") {
-this.appRunScript ("assign bond [{" + value + "}] \"" + this.pickBondAssignType + "\"");
+this.appRunScript ("modelkit assign bond [{" + value + "}] \"" + this.pickBondAssignType + "\"");
 return null;
-}if (name === "assignbond") {
-var data = value;
-return this.assignBond (data[0], String.fromCharCode (data[1]));
 }if (name === "atomtype") {
 if (value != null) {
 this.pickAtomAssignType = value;
@@ -321,15 +329,6 @@ this.setBondIndex ((value).intValue (), false);
 if (value != null) {
 this.setBondIndex ((value).intValue (), true);
 }return (this.bondIndex < 0 ? null : Integer.$valueOf (this.bondIndex));
-}if (name === "addhydrogen" || name === "addhydrogens") {
-if (value != null) this.addXtalHydrogens = J.modelkit.ModelKitPopup.isTrue (value);
-return Boolean.$valueOf (this.addXtalHydrogens);
-}if (name === "clicktosetelement") {
-if (value != null) this.clickToSetElement = J.modelkit.ModelKitPopup.isTrue (value);
-return Boolean.$valueOf (this.clickToSetElement);
-}if (name === "showsymopinfo") {
-if (value != null) this.showSymopInfo = J.modelkit.ModelKitPopup.isTrue (value);
-return Boolean.$valueOf (this.showSymopInfo);
 }if (name === "offset") {
 if (value === "none") {
 this.viewOffset = null;
@@ -363,6 +362,13 @@ J.modelkit.ModelKitPopup.notImplemented ("setProperty: removeConstraint");
 }if (name === "removeallconstraints") {
 J.modelkit.ModelKitPopup.notImplemented ("setProperty: removeAllConstraints");
 }System.err.println ("ModelKitPopup.setProperty? " + name + " " + value);
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+return "?";
+} else {
+throw e;
+}
+}
 return null;
 }, "~S,~O");
 c$.isTrue = Clazz.defineMethod (c$, "isTrue", 
@@ -371,6 +377,10 @@ return (Boolean.$valueOf (value.toString ()) === Boolean.TRUE);
 }, "~O");
 Clazz.defineMethod (c$, "getData", 
  function (key) {
+this.addData ("clickToSetElement", Boolean.$valueOf (this.clickToSetElement));
+this.addData ("addHydrogens", Boolean.$valueOf (this.addXtalHydrogens));
+this.addData ("isMolecular", Boolean.$valueOf (this.getMKState () == 0));
+this.addData ("showSymopInfo", Boolean.$valueOf (this.showSymopInfo));
 this.addData ("centerPoint", this.centerPoint);
 this.addData ("centerAtomIndex", Integer.$valueOf (this.centerAtomIndex));
 this.addData ("secondAtomIndex", Integer.$valueOf (this.secondAtomIndex));
@@ -513,8 +523,13 @@ break;
 }
 });
 Clazz.defineMethod (c$, "assignAtom", 
- function (atomIndex, type, autoBond, addHsAndBond) {
-this.vwr.ms.clearDB (atomIndex);
+ function (atomIndex, type, autoBond, addHsAndBond, isClick) {
+if (isClick) {
+if (this.isVwrRotateBond ()) {
+this.bondAtomIndex1 = atomIndex;
+return;
+}if (this.processAtomClick (atomIndex) || !this.clickToSetElement && this.vwr.ms.getAtom (atomIndex).getElementNumber () != 1) return;
+}this.vwr.ms.clearDB (atomIndex);
 if (type == null) type = "C";
 var atom = this.vwr.ms.at[atomIndex];
 var bs =  new JU.BS ();
@@ -561,7 +576,7 @@ bs = this.vwr.getModelUndeletedAtomsBitSet (atom.mi);
 bs.andNot (this.vwr.ms.getAtomBitsMDa (1612709900, null,  new JU.BS ()));
 this.vwr.ms.makeConnections2 (0.1, 1.8, 1, 1073741904, bsA, bs, null, false, false, 0);
 }if (this.addXtalHydrogens) this.vwr.addHydrogens (bsA, 1);
-}, "~N,~S,~B,~B");
+}, "~N,~S,~B,~B,~B");
 Clazz.defineMethod (c$, "assignBond", 
  function (bondIndex, type) {
 var bondOrder = type.charCodeAt (0) - 48;
@@ -861,12 +876,12 @@ var isCharge = this.$isPickAtomAssignCharge;
 var atomType = this.pickAtomAssignType;
 if (mp.count == 2) {
 this.vwr.undoMoveActionClear (-1, 4146, true);
-this.appRunScript ("assign connect " + mp.getMeasurementScript (" ", false));
+this.appRunScript ("modelkit connect " + mp.getMeasurementScript (" ", false) + " true");
 } else if (atomType.equals ("Xx")) {
 return false;
 } else {
 if (inRange) {
-var s = "assign atom ({" + dragAtomIndex + "}) \"" + atomType + "\"";
+var s = "modelkit assign atom ({" + dragAtomIndex + "}) \"" + atomType + "\" true";
 if (isCharge) {
 s += ";{atomindex=" + dragAtomIndex + "}.label='%C'; ";
 this.vwr.undoMoveActionClear (dragAtomIndex, 4, true);
@@ -877,7 +892,7 @@ this.vwr.undoMoveActionClear (-1, 4146, true);
 this.vwr.undoMoveActionClear (-1, 4146, true);
 var a = this.vwr.ms.at[dragAtomIndex];
 if (a.getElementNumber () == 1) {
-this.vwr.assignAtom (dragAtomIndex, "X", null);
+this.assignAtomClick (dragAtomIndex, "X", null);
 } else {
 var x = dragged.x;
 var y = dragged.y;
@@ -886,11 +901,90 @@ x <<= 1;
 y <<= 1;
 }var ptNew = JU.P3.new3 (x, y, a.sZ);
 this.vwr.tm.unTransformPoint (ptNew, ptNew);
-this.vwr.assignAtom (dragAtomIndex, atomType, ptNew);
+this.assignAtomClick (dragAtomIndex, atomType, ptNew);
 }}}return true;
 }, "JV.MouseState,JV.MouseState,JM.MeasurementPending,~N");
+Clazz.defineMethod (c$, "cmdAssignAtom", 
+function (atomIndex, pt, type, cmd, isClick) {
+if (isClick && type.equals ("X")) this.vwr.setModelKitRotateBondIndex (-1);
+var ac = this.vwr.ms.ac;
+if (pt == null) {
+if (atomIndex < 0) return;
+this.vwr.sm.modifySend (atomIndex, this.vwr.ms.at[atomIndex].mi, 1, cmd);
+this.assignAtom (atomIndex, type, true, true, true);
+if (!JU.PT.isOneOf (type, ";Mi;Pl;X;")) this.vwr.ms.setAtomNamesAndNumbers (0, -ac, null);
+this.vwr.sm.modifySend (atomIndex, this.vwr.ms.at[atomIndex].mi, -1, "OK");
+this.vwr.refresh (3, "assignAtom");
+return;
+}var atom = (atomIndex < 0 ? null : this.vwr.ms.at[atomIndex]);
+var bs = (atomIndex < 0 ?  new JU.BS () : JU.BSUtil.newAndSetBit (atomIndex));
+var pts =  Clazz.newArray (-1, [pt]);
+var vConnections =  new JU.Lst ();
+var modelIndex = -1;
+if (atom != null) {
+vConnections.addLast (atom);
+modelIndex = atom.mi;
+this.vwr.sm.modifySend (atomIndex, modelIndex, 3, cmd);
+}try {
+var isMK = this.vwr.getBoolean (603983903);
+if (!isMK) this.vwr.setBooleanProperty ("modelkitmode", true);
+bs = this.vwr.addHydrogensInline (bs, vConnections, pts);
+if (!isMK) this.vwr.setBooleanProperty ("modelkitmode", false);
+var atomIndex2 = bs.nextSetBit (0);
+this.assignAtom (atomIndex2, type, false, atomIndex >= 0, true);
+atomIndex = atomIndex2;
+} catch (ex) {
+if (Clazz.exceptionOf (ex, Exception)) {
+} else {
+throw ex;
+}
+}
+this.vwr.ms.setAtomNamesAndNumbers (0, -ac, null);
+this.vwr.sm.modifySend (atomIndex, modelIndex, -3, "OK");
+}, "~N,JU.P3,~S,~S,~B");
+Clazz.defineMethod (c$, "cmdAssignBond", 
+function (bondIndex, type, cmd) {
+var modelIndex = -1;
+try {
+modelIndex = this.vwr.ms.bo[bondIndex].atom1.mi;
+var ac = this.vwr.ms.ac;
+this.vwr.sm.modifySend (bondIndex, modelIndex, 2, cmd);
+var bsAtoms = this.assignBond (bondIndex, type);
+this.vwr.ms.setAtomNamesAndNumbers (0, -ac, null);
+if (bsAtoms == null || type == '0') this.vwr.refresh (3, "setBondOrder");
+this.vwr.sm.modifySend (bondIndex, modelIndex, -2, "" + type);
+} catch (ex) {
+if (Clazz.exceptionOf (ex, Exception)) {
+JU.Logger.error ("assignBond failed");
+this.vwr.sm.modifySend (bondIndex, modelIndex, -2, "ERROR " + ex);
+} else {
+throw ex;
+}
+}
+}, "~N,~S,~S");
+Clazz.defineMethod (c$, "cmdAssignConnect", 
+function (index, index2, cmd, isClick) {
+var connections = JU.AU.newFloat2 (1);
+connections[0] =  Clazz.newFloatArray (-1, [index, index2]);
+var modelIndex = this.vwr.ms.at[index].mi;
+this.vwr.sm.modifySend (index, modelIndex, 2, cmd);
+this.vwr.ms.connect (connections);
+var ac = this.vwr.ms.ac;
+this.assignAtom (index, ".", true, true, isClick);
+this.assignAtom (index2, ".", true, true, isClick);
+this.vwr.ms.setAtomNamesAndNumbers (0, -ac, null);
+this.vwr.sm.modifySend (index, modelIndex, -2, "OK");
+this.vwr.refresh (3, "assignConnect");
+}, "~N,~N,~S,~B");
+Clazz.defineMethod (c$, "assignAtomClick", 
+function (atomIndex, element, ptNew) {
+this.vwr.script ("modelkit assign atom ({" + atomIndex + "}) \"" + element + "\" " + (ptNew == null ? "" : JU.Escape.eP (ptNew)) + " true");
+}, "~N,~S,JU.P3");
 Clazz.defineStatics (c$,
-"MAX_LABEL", 32);
+"MAX_LABEL", 32,
+"ATOM_MENU", "atomMenu",
+"BOND_MENU", "bondMenu",
+"XTAL_MENU", "xtalMenu");
 c$.bundle = c$.prototype.bundle =  new J.modelkit.ModelKitPopupResourceBundle (null, null);
 Clazz.defineStatics (c$,
 "STATE_BITS_XTAL", 0x03,
