@@ -14,6 +14,7 @@ this.elementNumberMax = 0;
 this.altElementMax = 0;
 this.mf = null;
 this.atomList = null;
+this.atNos = null;
 Clazz.instantialize (this, arguments);
 }, JU, "JmolMolecule");
 Clazz.prepareFields (c$, function () {
@@ -70,23 +71,28 @@ return m.getMolecularFormula (false, wts, isEmpirical);
 }, "~A,JU.BS,~A,~B");
 Clazz.defineMethod (c$, "getMolecularFormula", 
 function (includeMissingHydrogens, wts, isEmpirical) {
-return this.getMolecularFormulaImpl (includeMissingHydrogens, wts, isEmpirical, true);
+return this.getMolecularFormulaImpl (includeMissingHydrogens, wts, isEmpirical);
 }, "~B,~A,~B");
 Clazz.defineMethod (c$, "getMolecularFormulaImpl", 
-function (includeMissingHydrogens, wts, isEmpirical, includeH) {
+function (includeMissingHydrogens, wts, isEmpirical) {
 if (this.mf != null) return this.mf;
 if (this.atomList == null) {
 this.atomList =  new JU.BS ();
-this.atomList.setBits (0, this.nodes.length);
+this.atomList.setBits (0, this.atNos == null ? this.nodes.length : this.atNos.length);
 }this.elementCounts =  Clazz.newIntArray (JU.Elements.elementNumberMax, 0);
 this.altElementCounts =  Clazz.newIntArray (JU.Elements.altElementMax, 0);
 this.ac = this.atomList.cardinality ();
 this.nElements = 0;
 for (var p = 0, i = this.atomList.nextSetBit (0); i >= 0; i = this.atomList.nextSetBit (i + 1), p++) {
-var node = this.nodes[i];
+var n;
+var node = null;
+if (this.atNos == null) {
+node = this.nodes[i];
 if (node == null) continue;
-var n = node.getAtomicAndIsotopeNumber ();
-var f = (wts == null ? 1 : Clazz.floatToInt (8 * wts[p]));
+n = node.getAtomicAndIsotopeNumber ();
+} else {
+n = this.atNos[i];
+}var f = (wts == null ? 1 : Clazz.floatToInt (8 * wts[p]));
 if (n < JU.Elements.elementNumberMax) {
 if (this.elementCounts[n] == 0) this.nElements++;
 this.elementCounts[n] += f;
@@ -143,7 +149,7 @@ mf += sep + JU.Elements.elementSymbolFromNumber (JU.Elements.altElementNumberFro
 sep = " ";
 }}
 return mf;
-}, "~B,~A,~B,~B");
+}, "~B,~A,~B");
 c$.initialize = Clazz.defineMethod (c$, "initialize", 
  function (nodes, moleculeIndex, firstAtomIndex, atomList, modelIndex, indexInModel) {
 var jm =  new JU.JmolMolecule ();
