@@ -75,9 +75,9 @@ w.equalsIgnoreCase("vanderwaals")?r=(m+1<a.length&&2==a[m+1].tok?a[++m].asInt():
 r,J.atomdata.RadiusData.EnumType.FACTOR,J.c.VDW.AUTO);a=this.vwr.newMeasurementData(null,d).set(0,null,m,b,g,h,null,k,j,null,!0,0,0,null,NaN).getMeasurements(K,x);return e.addXObj(a);case 134217729:if(3!=(c=a.length)&&4!=c)return!1;break;default:if(2!=(c=a.length))return!1}b=Array(c);for(m=0;m<c;m++)if(null==(b[m]=e.ptValue(a[m],null)))return!1;switch(c){case 2:return e.addXFloat(b[0].distance(b[1]));case 3:return e.addXFloat(JU.Measure.computeAngleABC(b[0],b[1],b[2],!0));case 4:return e.addXFloat(JU.Measure.computeTorsion(b[0],
 b[1],b[2],b[3],!0))}return!1},"JS.ScriptMathProcessor,~A,~N");n(c$,"evaluateModulation",function(e,a){var b="",c=NaN,d=null;switch(a.length){case 0:break;case 1:switch(a[0].tok){case 8:d=a[0].value;break;case 4:b=a[0].asString();break;default:c=JS.SV.fValue(a[0])}break;case 2:b=JS.SV.sValue(a[0]);c=JS.SV.fValue(a[1]);break;default:return!1}null==d&&1E6>c&&(d=JU.P3.new3(c,c,c));c=e.getX();c=10==c.tok?c.value:new JU.BS;return e.addXList(this.vwr.ms.getModulationList(c,(b+"D").toUpperCase().charAt(0),
 d))},"JS.ScriptMathProcessor,~A");n(c$,"evaluatePlane",function(e,a,b){if(134219265==b&&3!=a.length||134217763==b&&2!=a.length&&3!=a.length&&4!=a.length||0==a.length||4<a.length)return!1;var c,d,f=JS.ScriptMathProcessor.planeValue(a[0]),g,h;switch(a.length){case 1:return 10==a[0].tok&&(a=a[0].value,3==a.cardinality())?(a=this.vwr.ms.getAtomPointVector(a),e.addXPt4(JU.Measure.getPlaneThroughPoints(a.get(0),a.get(1),a.get(2),new JU.V3,new JU.V3,new JU.P4))):null!=f&&e.addXPt4(f);case 2:if(134217763==
-b){c=JS.ScriptMathProcessor.planeValue(a[1]);if(null==c)return!1;b=new JU.P3;g=new JU.V3;h=new JU.V3;if(null!=f)return a=JU.Measure.getIntersectionPP(f,c),null==a?e.addXStr(""):e.addXList(a);d=e.ptValue(a[0],null);return null==d?e.addXStr(""):e.addXPt(JU.Measure.getIntersection(d,null,c,b,g,h))}case 3:case 4:switch(b){case 134219265:return e.addXPt4(this.e.getHklPlane(JU.P3.new3(JS.SV.fValue(a[0]),JS.SV.fValue(a[1]),JS.SV.fValue(a[2]))));case 134217763:c=e.ptValue(a[0],null);d=e.ptValue(a[1],null);
-if(null==c||null==d)return e.addXStr("");d=JU.V3.newV(d);d.normalize();f=JS.ScriptMathProcessor.planeValue(a[2]);if(null!=f)return b=new JU.P3,g=new JU.V3,h=new JU.V3,c=JU.Measure.getIntersection(c,d,f,b,g,h),null==c?e.addXStr(""):e.addXPt(c);b=e.ptValue(a[2],null);if(null==b)return e.addXStr("");g=new JU.V3;b=JU.P3.newP(b);if(3==a.length)return JU.Measure.projectOntoAxis(b,c,d,g),e.addXPt(b);f=JS.SV.fValue(a[3]);a=JU.P3.newP(b);JU.Measure.projectOntoAxis(b,c,d,g);a=a.distance(b);c=new JU.Lst;a==
-f?c.addLast(b):a<f&&(a=Math.sqrt(f*f-a*a),g.scaleAdd2(a,d,b),c.addLast(JU.P3.newP(g)),g.scaleAdd2(-a,d,b),c.addLast(JU.P3.newP(g)));return e.addXList(c)}switch(a[0].tok){case 2:case 3:if(3==a.length)return f=JS.SV.fValue(a[0]),b=JS.SV.fValue(a[1]),a=JS.SV.fValue(a[2]),g=JU.V3.new3(0,0,1),d=JU.P3.new3(0,1,0),a=JU.Quat.newVA(d,a),a.getMatrix().rotate(g),d.set(0,0,1),a=JU.Quat.newVA(d,b),a.getMatrix().rotate(g),d.setT(g),d.scale(f),f=new JU.P4,JU.Measure.getPlaneThroughPoint(d,g,f),e.addXPt4(f);break;
+b){c=JS.ScriptMathProcessor.planeValue(a[1]);if(null==c)return!1;b=new JU.P3;g=new JU.V3;h=new JU.V3;if(null!=f)return a=JU.Measure.getIntersectionPP(f,c),null==a?e.addXStr(""):e.addXList(a);d=e.ptValue(a[0],null);return null==d?e.addXStr(""):e.addXPt(JU.Measure.getIntersection(d,null,c,b,g,h))}case 3:case 4:switch(b){case 134219265:return e.addXPt4(this.e.getHklPlane(JU.P3.new3(JS.SV.fValue(a[0]),JS.SV.fValue(a[1]),JS.SV.fValue(a[2])),NaN,!1));case 134217763:c=e.ptValue(a[0],null);d=e.ptValue(a[1],
+null);if(null==c||null==d)return e.addXStr("");d=JU.V3.newV(d);d.normalize();f=JS.ScriptMathProcessor.planeValue(a[2]);if(null!=f)return b=new JU.P3,g=new JU.V3,h=new JU.V3,c=JU.Measure.getIntersection(c,d,f,b,g,h),null==c?e.addXStr(""):e.addXPt(c);b=e.ptValue(a[2],null);if(null==b)return e.addXStr("");g=new JU.V3;b=JU.P3.newP(b);if(3==a.length)return JU.Measure.projectOntoAxis(b,c,d,g),e.addXPt(b);f=JS.SV.fValue(a[3]);a=JU.P3.newP(b);JU.Measure.projectOntoAxis(b,c,d,g);a=a.distance(b);c=new JU.Lst;
+a==f?c.addLast(b):a<f&&(a=Math.sqrt(f*f-a*a),g.scaleAdd2(a,d,b),c.addLast(JU.P3.newP(g)),g.scaleAdd2(-a,d,b),c.addLast(JU.P3.newP(g)));return e.addXList(c)}switch(a[0].tok){case 2:case 3:if(3==a.length)return f=JS.SV.fValue(a[0]),b=JS.SV.fValue(a[1]),a=JS.SV.fValue(a[2]),g=JU.V3.new3(0,0,1),d=JU.P3.new3(0,1,0),a=JU.Quat.newVA(d,a),a.getMatrix().rotate(g),d.set(0,0,1),a=JU.Quat.newVA(d,b),a.getMatrix().rotate(g),d.setT(g),d.scale(f),f=new JU.P4,JU.Measure.getPlaneThroughPoint(d,g,f),e.addXPt4(f);break;
 case 10:case 8:c=e.ptValue(a[0],null);d=e.ptValue(a[1],null);if(null==d)return!1;b=2<a.length&&(10==a[2].tok||8==a[2].tok)?e.ptValue(a[2],null):null;g=JU.V3.newV(d);if(null==b)return f=new JU.P4,2==a.length||2!=a[2].tok&&3!=a[2].tok&&!a[2].asBoolean()?(b=JU.P3.newP(c),b.add(d),b.scale(0.5),g.sub(c),g.normalize()):1073742335==a[2].tok?b=c:(g.sub(c),b=new JU.P3,b.scaleAdd2(a[2].asFloat(),g,c)),JU.Measure.getPlaneThroughPoint(b,g,f),e.addXPt4(f);f=new JU.V3;a=4==a.length?e.ptValue(a[3],null):null;a=
 JU.Measure.getDirectedNormalThroughPoints(c,d,b,a,g,f);return e.addXPt4(JU.P4.new4(g.x,g.y,g.z,a))}}if(4!=a.length)return!1;b=JS.SV.fValue(a[0]);g=JS.SV.fValue(a[1]);c=JS.SV.fValue(a[2]);a=JS.SV.fValue(a[3]);return e.addXPt4(JU.P4.new4(b,g,c,a))},"JS.ScriptMathProcessor,~A,~N");n(c$,"evaluatePoint",function(e,a){switch(a.length){default:return!1;case 1:if(3==a[0].tok||2==a[0].tok)return e.addXInt(a[0].asInt());var b=null;if(7==a[0].tok){var c=a[0].getList(),d=c.size();if(0==d)return!1;switch(c.get(0).tok){case 4:b=
 c.get(0).value;if(!b.startsWith("{")||r(JU.Escape.uP(b),String))break;for(var b=new JU.Lst,f=0;f<d;f++)b.addLast(JS.SV.getVariable(JU.Escape.uP(JS.SV.sValue(c.get(f)))));return e.addXList(b)}b="{"+JS.SV.sValue(a[0])+"}"}null==b&&(b=JS.SV.sValue(a[0]));c=JU.Escape.uP(b);return r(c,JU.P3)?e.addXPt(c):e.addXStr(""+c);case 2:switch(a[1].tok){case 1073742334:case 1073742335:switch(a[0].tok){case 8:c=JU.P3.newP(a[0].value);break;case 10:c=this.vwr.ms.getAtomSetCenter(a[0].value);break;default:return!1}1073742335==
@@ -109,7 +109,7 @@ var c=0,d=a[0].value,f=""+d,g=a[0].tok;4==g&&(g=JS.T.getTokFromName(f));var h=th
 if(g.equalsIgnoreCase("group"))l=!0,g=1086324742;else if(g.equalsIgnoreCase("vanderwaals")||g.equalsIgnoreCase("vdw"))d=null,k=!0,g=1648363544;else if(g.equalsIgnoreCase("unitcell"))g=1814695966;else return!1}break;case 7:1==b&&(d=a[0].asString(),g=0);break;case 1073742328:return 3==b&&r(a[1].value,JU.BS)&&r(a[2].value,JU.BS)&&e.addXBs(this.vwr.getBranchBitSet(a[2].value.nextSetBit(0),a[1].value.nextSetBit(0),!0));case 134218757:case 1237320707:case 134218756:c=null;d=!0;switch(b){case 2:break;case 3:if(d=
 10==a[2].tok)c=a[2].value;break;default:d=!1}d||this.e.invArg();return e.addXObj(this.e.getSmilesExt().getSmilesMatches(JS.SV.sValue(a[1]),null,c,null,134218756==g?2:1,e.asBitSet,!1))}if(r(d,String)){if(0==g){g=1073742362;if(2<b)return!1;b=2}}else if(!p)return!1;switch(b){case 1:switch(g){case 136314895:case 2097184:case 1678381065:return e.addXBs(h.getAtoms(g,null));case 1073741863:return e.addXBs(h.getAtoms(g,""));case 1073742362:return e.addXBs(h.getAtoms(1086324744,f))}return!1;case 2:switch(g){case 1073742362:g=
 1086324744;break;case 1073741824:case 1086326786:case 1086326785:case 1073741863:case 1086324744:case 1111490587:case 1073742128:case 1073741925:case 1073742189:return e.addXBs(this.vwr.ms.getAtoms(g,JS.SV.sValue(a[1])));case 1094713349:case 1094713350:return e.addXBs(this.vwr.ms.getAtoms(g,JS.SV.ptValue(a[1])))}break;case 3:switch(g){case 1073742335:case 1073742334:case 1086324742:case 1648363544:case 1814695966:case 134217750:case 134219265:case 1073742329:case 8:case 7:break;case 1086324744:f=
-JS.SV.sValue(a[2]);break;default:return!1}}var n=null,d=b=null,v=a.length-1;switch(a[v].tok){case 9:n=a[v].value;break;case 8:b=a[v].value;JS.SV.sValue(a[1]).equalsIgnoreCase("hkl")&&(n=this.e.getHklPlane(b));break;case 7:d=2==v&&7==a[1].tok?a[1].getList():null,b=2==v?JS.SV.ptValue(a[1]):1==v?JU.P3.new3(NaN,0,0):null}if(null!=n)return e.addXBs(h.getAtomsNearPlane(c,n));h=10==a[v].tok?a[v].value:null;if(0<v&&null==b&&null==d&&null==h)return!1;if(1814695966==g)return(null!=h||null!=b)&&e.addXObj(this.vwr.ms.getUnitCellPointsWithin(c,
+JS.SV.sValue(a[2]);break;default:return!1}}var n=null,d=b=null,v=a.length-1;switch(a[v].tok){case 9:n=a[v].value;break;case 8:b=a[v].value;JS.SV.sValue(a[1]).equalsIgnoreCase("hkl")&&(n=this.e.getHklPlane(b,NaN,!1));break;case 7:d=2==v&&7==a[1].tok?a[1].getList():null,b=2==v?JS.SV.ptValue(a[1]):1==v?JU.P3.new3(NaN,0,0):null}if(null!=n)return e.addXBs(h.getAtomsNearPlane(c,n));h=10==a[v].tok?a[v].value:null;if(0<v&&null==b&&null==d&&null==h)return!1;if(1814695966==g)return(null!=h||null!=b)&&e.addXObj(this.vwr.ms.getUnitCellPointsWithin(c,
 h,b,j));if(null!=b||null!=d){if(7==a[v].tok){k=a[v].getList();g=Array(k.size());for(f=g.length;0<=--f;)g[f]=JS.SV.ptValue(k.get(f));k=null;if(null!=d){k=Array(d.size());for(f=k.length;0<=--f;)k[f]=JS.SV.ptValue(d.get(f))}d=Array(1);switch(J.bspt.PointIterator.withinDistPoints(c,b,g,k,d)){case 134217751:return e.addXPt(d[0]);case 1073742001:return e.addXList(d[0]);case 1275068418:return e.addXAI(d[0]);case 4:return e.addXStr(d[0]);default:return!1}}return e.addXBs(this.vwr.getAtomsNearPt(c,b))}if(1086324744==
 g)return e.addXBs(this.vwr.ms.getSequenceBits(f,h,new JU.BS));null==h&&(h=new JU.BS);if(!p)try{return e.addXBs(this.vwr.ms.getAtoms(g,h))}catch(x){if(K(x,Exception))return!1;throw x;}if(l)return e.addXBs(this.vwr.getGroupsWithin(S(c),h));k&&(m=new J.atomdata.RadiusData(null,10<c?c/100:c,10<c?J.atomdata.RadiusData.EnumType.FACTOR:J.atomdata.RadiusData.EnumType.OFFSET,J.c.VDW.AUTO),0>c&&(c=0));return e.addXBs(this.vwr.ms.getAtomsWithinRadius(c,h,j,m))},"JS.ScriptMathProcessor,~A");n(c$,"evaluateWrite",
 function(e,a){switch(a.length){case 0:return!1;case 1:var b=a[0].asString().toUpperCase();if(b.equals("PNGJ"))return e.addXMap(this.vwr.fm.getFileAsMap(null,"PNGJ"));if(JU.PT.isOneOf(b,";ZIP;ZIPALL;JMOL;")){var c=new java.util.Hashtable,d=new JU.OC;c.put("outputChannel",d);this.vwr.createZip(null,b,c);b=JU.Rdr.getBIS(d.toByteArray());c=new java.util.Hashtable;this.vwr.readFileAsMap(b,c,null);return e.addXMap(c)}}return e.addXStr(this.e.getCmdExt().dispatch(134221856,!0,a))},"JS.ScriptMathProcessor,~A");
